import fnmatch
from distutils.command.check import check
from distutils.filelist import FileList


class sdist_check(check):
    description = "To come..."
    user_options = []
    description = ("perform additional checks on sdists")

    user_options = [
        ('metadata', 'm', 'Verify meta-data'),
        ('restructuredtext', 'r', (
            'Checks if long string meta-data syntax '
            'are reStructuredText-compliant')),
        ('strict', 's', 'Will exit with an error if a check fails'),
        ('badfiles=', 'b', 'Check files included in dist for unusual names'),
    ]

    boolean_options = ['metadata', 'restructuredtext', 'strict']

    def initialize_options(self):
        check.initialize_options(self)
        self.badfiles = None

    def finalize_options(self):
        if self.badfiles is None:
            self.badfiles = ["*~", ]
        self.ensure_string_list('badfiles')

    def _get_sdist_filelist(self):
        """Get a filelist as would be contained in sdist.
        """
        sdist = self.distribution.get_command_obj('sdist')
        sdist.ensure_finalized()
        sdist.filelist = FileList()
        sdist.get_file_list()
        self.sdist_files = sdist.filelist
        return sdist.filelist

    def run(self):
        self.check_bad_filenames()
        check.run(self)

    def check_bad_filenames(self):
        """Checks if there are unusual filenames contained in sdist.
        """
        filelist = self._get_sdist_filelist()
        for pattern in self.badfiles:
            matches = fnmatch.filter(filelist.files, pattern)
            for match in matches:
                self.warn("suspicious filename found for distribution: %s"
                          % match)



import os
import sys
from setuptools import setup
from setuptools.command.test import test as TestCommand

tests_path = os.path.join(os.path.dirname(__file__), 'tests')


class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test"), ]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = []

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args)
        sys.exit(errno)                                # pragma: no cover


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

install_requires = [
    'setuptools',
    ]

tests_require = [
    'pytest >= 2.0.3',
    'pytest-xdist',
    'pytest-cov',
    'docutils',
    ]

docs_require = [
    'Sphinx',
    ]

setup(
    name="sdist_check",
    version="0.1",
    author="Uli Fouquet",
    author_email="uli@gnufix.de",
    description=(
        "setuptools sdist checker."),
    license="MIT",
    keywords="setuptools sdist check",
    url="https://github.com/ulif/sdist_check/",
    py_modules=["sdist_check", ],
    packages=[],
    namespace_packages=[],
    long_description=read('README.rst') + '\n\n\n' + read('CHANGES.rst'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: System Administrators",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    include_package_data=False,
    zip_safe=False,
    install_requires=install_requires,
    tests_require=tests_require,
    extras_require=dict(
        tests=tests_require,
        docs=docs_require,
        ),
    cmdclass={'test': PyTest},
    entry_points={
        "distutils.commands": [
            "sdist_check = sdist_check:sdist_check",
        ],
    },
)
